.. _homogenization-perfusion_micro:

homogenization/perfusion_micro.py
=================================

**Description**


Homogenization of the Darcy flow in a thin porous layer.

The reference cell is composed of the matrix representing the dual porosity
and of two disconnected channels representing the primary porosity,
see paper [1].

[1] E. Rohan, V. Lukeš: Modeling Tissue Perfusion Using a Homogenized
Model with Layer-wise Decomposition. IFAC Proceedings Volumes 45(2), 2012,
pages 1029-1034.
https://doi.org/10.3182/20120215-3-AT-3016.00182


.. image:: /../doc/images/gallery/homogenization-perfusion_micro_etaA_YM.png
.. image:: /../doc/images/gallery/homogenization-perfusion_micro_etaB_YM.png
.. image:: /../doc/images/gallery/homogenization-perfusion_micro_gamma_p_YM.png


:download:`source code </../sfepy/examples/homogenization/perfusion_micro.py>`

.. literalinclude:: /../sfepy/examples/homogenization/perfusion_micro.py

